@@ -12,11 +12,11 @@
 
 from openstack.compute import compute_service
 from openstack.compute.v2 import metadata
-from openstack import resource2
+from openstack import resource
 from openstack import utils
 
 
-class Server(resource2.Resource, metadata.MetadataMixin):
+class Server(resource.Resource, metadata.MetadataMixin):
     resource_key = 'server'
     resources_key = 'servers'
     base_path = '/servers'
@@ -29,115 +29,116 @@ class Server(resource2.Resource, metadata.MetadataMixin):
     allow_delete = True
     allow_list = True
 
-    _query_mapping = resource2.QueryParameters("image", "flavor", "name",
-                                               "status", "host", "all_tenants",
-                                               "sort_key", "sort_dir",
-                                               "reservation_id", "tags",
-                                               "project_id",
-                                               tags_any="tags-any",
-                                               not_tags="not-tags",
-                                               not_tags_any="not-tags-any",
-                                               is_deleted="deleted",
-                                               ipv4_address="ip",
-                                               ipv6_address="ip6",
-                                               changes_since="changes-since")
+    _query_mapping = resource.QueryParameters(
+        "image", "flavor", "name",
+        "status", "host", "all_tenants",
+        "sort_key", "sort_dir",
+        "reservation_id", "tags",
+        "project_id",
+        tags_any="tags-any",
+        not_tags="not-tags",
+        not_tags_any="not-tags-any",
+        is_deleted="deleted",
+        ipv4_address="ip",
+        ipv6_address="ip6",
+        changes_since="changes-since")
 
     #: A list of dictionaries holding links relevant to this server.
-    links = resource2.Body('links')
+    links = resource.Body('links')
 
-    access_ipv4 = resource2.Body('accessIPv4')
-    access_ipv6 = resource2.Body('accessIPv6')
+    access_ipv4 = resource.Body('accessIPv4')
+    access_ipv6 = resource.Body('accessIPv6')
     #: A dictionary of addresses this server can be accessed through.
     #: The dictionary contains keys such as ``private`` and ``public``,
     #: each containing a list of dictionaries for addresses of that type.
     #: The addresses are contained in a dictionary with keys ``addr``
     #: and ``version``, which is either 4 or 6 depending on the protocol
     #: of the IP address. *Type: dict*
-    addresses = resource2.Body('addresses', type=dict)
+    addresses = resource.Body('addresses', type=dict)
     #: Timestamp of when the server was created.
-    created_at = resource2.Body('created')
+    created_at = resource.Body('created')
     #: The flavor reference, as a ID or full URL, for the flavor to use for
     #: this server.
-    flavor_id = resource2.Body('flavorRef')
+    flavor_id = resource.Body('flavorRef')
     #: The flavor property as returned from server.
-    flavor = resource2.Body('flavor', type=dict)
+    flavor = resource.Body('flavor', type=dict)
     #: An ID representing the host of this server.
-    host_id = resource2.Body('hostId')
+    host_id = resource.Body('hostId')
     #: The image reference, as a ID or full URL, for the image to use for
     #: this server.
-    image_id = resource2.Body('imageRef')
+    image_id = resource.Body('imageRef')
     #: The image property as returned from server.
-    image = resource2.Body('image', type=dict)
+    image = resource.Body('image', type=dict)
     #: Metadata stored for this server. *Type: dict*
-    metadata = resource2.Body('metadata', type=dict)
+    metadata = resource.Body('metadata', type=dict)
     #: While the server is building, this value represents the percentage
     #: of completion. Once it is completed, it will be 100.  *Type: int*
-    progress = resource2.Body('progress', type=int)
+    progress = resource.Body('progress', type=int)
     #: The ID of the project this server is associated with.
-    project_id = resource2.Body('tenant_id')
+    project_id = resource.Body('tenant_id')
     #: The state this server is in. Valid values include ``ACTIVE``,
     #: ``BUILDING``, ``DELETED``, ``ERROR``, ``HARD_REBOOT``, ``PASSWORD``,
     #: ``PAUSED``, ``REBOOT``, ``REBUILD``, ``RESCUED``, ``RESIZED``,
     #: ``REVERT_RESIZE``, ``SHUTOFF``, ``SOFT_DELETED``, ``STOPPED``,
     #: ``SUSPENDED``, ``UNKNOWN``, or ``VERIFY_RESIZE``.
-    status = resource2.Body('status')
+    status = resource.Body('status')
     #: Timestamp of when this server was last updated.
-    updated_at = resource2.Body('updated')
+    updated_at = resource.Body('updated')
     #: The ID of the owners of this server.
-    user_id = resource2.Body('user_id')
+    user_id = resource.Body('user_id')
     #: The name of an associated keypair
-    key_name = resource2.Body('key_name')
+    key_name = resource.Body('key_name')
     #: The disk configuration. Either AUTO or MANUAL.
-    disk_config = resource2.Body('OS-DCF:diskConfig')
+    disk_config = resource.Body('OS-DCF:diskConfig')
     #: Indicates whether a configuration drive enables metadata injection.
     #: Not all cloud providers enable this feature.
-    has_config_drive = resource2.Body('config_drive')
+    has_config_drive = resource.Body('config_drive')
     #: The name of the availability zone this server is a part of.
-    availability_zone = resource2.Body('OS-EXT-AZ:availability_zone')
+    availability_zone = resource.Body('OS-EXT-AZ:availability_zone')
     #: The power state of this server.
-    power_state = resource2.Body('OS-EXT-STS:power_state')
+    power_state = resource.Body('OS-EXT-STS:power_state')
     #: The task state of this server.
-    task_state = resource2.Body('OS-EXT-STS:task_state')
+    task_state = resource.Body('OS-EXT-STS:task_state')
     #: The VM state of this server.
-    vm_state = resource2.Body('OS-EXT-STS:vm_state')
+    vm_state = resource.Body('OS-EXT-STS:vm_state')
     #: A list of an attached volumes. Each item in the list contains at least
     #: an "id" key to identify the specific volumes.
-    attached_volumes = resource2.Body(
+    attached_volumes = resource.Body(
         'os-extended-volumes:volumes_attached')
     #: The timestamp when the server was launched.
-    launched_at = resource2.Body('OS-SRV-USG:launched_at')
+    launched_at = resource.Body('OS-SRV-USG:launched_at')
     #: The timestamp when the server was terminated (if it has been).
-    terminated_at = resource2.Body('OS-SRV-USG:terminated_at')
+    terminated_at = resource.Body('OS-SRV-USG:terminated_at')
     #: A list of applicable security groups. Each group contains keys for
     #: description, name, id, and rules.
-    security_groups = resource2.Body('security_groups')
+    security_groups = resource.Body('security_groups')
     #: When a server is first created, it provides the administrator password.
-    admin_password = resource2.Body('adminPass')
+    admin_password = resource.Body('adminPass')
     #: The file path and contents, text only, to inject into the server at
     #: launch. The maximum size of the file path data is 255 bytes.
     #: The maximum limit is The number of allowed bytes in the decoded,
     #: rather than encoded, data.
-    personality = resource2.Body('personality')
+    personality = resource.Body('personality')
     #: Configuration information or scripts to use upon launch.
     #: Must be Base64 encoded.
-    user_data = resource2.Body('OS-EXT-SRV-ATTR:user_data')
+    user_data = resource.Body('OS-EXT-SRV-ATTR:user_data')
     #: Enables fine grained control of the block device mapping for an
     #: instance. This is typically used for booting servers from volumes.
-    block_device_mapping = resource2.Body('block_device_mapping_v2')
+    block_device_mapping = resource.Body('block_device_mapping_v2')
     #: The dictionary of data to send to the scheduler.
-    scheduler_hints = resource2.Body('OS-SCH-HNT:scheduler_hints', type=dict)
+    scheduler_hints = resource.Body('OS-SCH-HNT:scheduler_hints', type=dict)
     #: A networks object. Required parameter when there are multiple
     #: networks defined for the tenant. When you do not specify the
     #: networks parameter, the server attaches to the only network
     #: created for the current tenant.
-    networks = resource2.Body('networks')
+    networks = resource.Body('networks')
     #: The hypervisor host name. Appears in the response for administrative
     #: users only.
-    hypervisor_hostname = resource2.Body('OS-EXT-SRV-ATTR:hypervisor_hostname')
+    hypervisor_hostname = resource.Body('OS-EXT-SRV-ATTR:hypervisor_hostname')
     #: The instance name. The Compute API generates the instance name from the
     #: instance name template. Appears in the response for administrative users
     #: only.
-    instance_name = resource2.Body('OS-EXT-SRV-ATTR:instance_name')
+    instance_name = resource.Body('OS-EXT-SRV-ATTR:instance_name')
 
     def _prepare_request(self, requires_id=True, prepend_key=True):
         request = super(Server, self)._prepare_request(requires_id=requires_id,
@@ -178,13 +179,18 @@ class Server(resource2.Resource, metadata.MetadataMixin):
         url = utils.urljoin(Server.base_path, self.id, 'action')
         headers = {'Accept': ''}
         return session.post(
-            url, endpoint_filter=self.service, json=body, headers=headers)
+            url, json=body, headers=headers)
 
     def change_password(self, session, new_password):
         """Change the administrator password to the given password."""
         body = {'changePassword': {'adminPass': new_password}}
         self._action(session, body)
 
+    def get_password(self, session):
+        """Get the encrypted administrator password."""
+        url = utils.urljoin(Server.base_path, self.id, 'os-server-password')
+        return session.get(url, endpoint_filter=self.service)
+
     def reboot(self, session, reboot_type):
         """Reboot server where reboot_type might be 'SOFT' or 'HARD'."""
         body = {'reboot': {'type': reboot_type}}
@@ -206,7 +212,7 @@ class Server(resource2.Resource, metadata.MetadataMixin):
             'preserve_ephemeral': preserve_ephemeral
         }
         if image is not None:
-            action['imageRef'] = resource2.Resource._get_id(image)
+            action['imageRef'] = resource.Resource._get_id(image)
         if access_ipv4 is not None:
             action['accessIPv4'] = access_ipv4
         if access_ipv6 is not None:
@@ -377,3 +383,5 @@ class ServerDetail(Server):
     allow_update = False
     allow_delete = False
     allow_list = True
+
+    detail_for = Server
