@@ -11,7 +11,7 @@
 # under the License.
 
 from openstack.network import network_service
-from openstack import resource2 as resource
+from openstack import resource
 
 
 class QoSBandwidthLimitRule(resource.Resource):
@@ -34,6 +34,5 @@ class QoSBandwidthLimitRule(resource.Resource):
     max_kbps = resource.Body('max_kbps')
     #: Maximum burst bandwidth in kbps.
     max_burst_kbps = resource.Body('max_burst_kbps')
-    # NOTE(ralonsoh): to be implemented in bug 1560961
     #: Traffic direction from the tenant point of view ('egress', 'ingress').
-    # direction = resource.prop('direction')
+    direction = resource.Body('direction')
