@@ -23,10 +23,10 @@ from openstack.compute.v2 import server_group
 from openstack.compute.v2 import server_interface
 from openstack.compute.v2 import server_ip
 from openstack.compute.v2 import service
-from openstack.tests.unit import test_proxy_base2
+from openstack.tests.unit import test_proxy_base
 
 
-class TestComputeProxy(test_proxy_base2.TestProxyBase):
+class TestComputeProxy(test_proxy_base.TestProxyBase):
     def setUp(self):
         super(TestComputeProxy, self).setUp()
         self.proxy = _proxy.Proxy(self.session)
@@ -36,7 +36,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
 
     def test_extensions(self):
         self.verify_list_no_kwargs(self.proxy.extensions, extension.Extension,
-                                   paginated=False)
+                                   paginated=True)
 
     def test_flavor_create(self):
         self.verify_create(self.proxy.create_flavor, flavor.Flavor)
@@ -126,7 +126,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
         test_interface.server_id = server_id
 
         # Case1: ServerInterface instance is provided as value
-        self._verify2("openstack.proxy2.BaseProxy._delete",
+        self._verify2("openstack.proxy.Proxy._delete",
                       self.proxy.delete_server_interface,
                       method_args=[test_interface],
                       method_kwargs={"server": server_id},
@@ -136,7 +136,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
                                        "ignore_missing": True})
 
         # Case2: ServerInterface ID is provided as value
-        self._verify2("openstack.proxy2.BaseProxy._delete",
+        self._verify2("openstack.proxy.Proxy._delete",
                       self.proxy.delete_server_interface,
                       method_args=[interface_id],
                       method_kwargs={"server": server_id},
@@ -163,7 +163,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
         test_interface.server_id = server_id
 
         # Case1: ServerInterface instance is provided as value
-        self._verify2('openstack.proxy2.BaseProxy._get',
+        self._verify2('openstack.proxy.Proxy._get',
                       self.proxy.get_server_interface,
                       method_args=[test_interface],
                       method_kwargs={"server": server_id},
@@ -172,7 +172,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
                                        "server_id": server_id})
 
         # Case2: ServerInterface ID is provided as value
-        self._verify2('openstack.proxy2.BaseProxy._get',
+        self._verify2('openstack.proxy.Proxy._get',
                       self.proxy.get_server_interface,
                       method_args=[interface_id],
                       method_kwargs={"server": server_id},
@@ -286,6 +286,138 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
                      expected_kwargs={"metadata": {"k1": "v1"},
                                       "image": id})
 
+    def test_add_fixed_ip_to_server(self):
+        self._verify("openstack.compute.v2.server.Server.add_fixed_ip",
+                     self.proxy.add_fixed_ip_to_server,
+                     method_args=["value", "network-id"],
+                     expected_args=["network-id"])
+
+    def test_fixed_ip_from_server(self):
+        self._verify("openstack.compute.v2.server.Server.remove_fixed_ip",
+                     self.proxy.remove_fixed_ip_from_server,
+                     method_args=["value", "address"],
+                     expected_args=["address"])
+
+    def test_floating_ip_to_server(self):
+        self._verify("openstack.compute.v2.server.Server.add_floating_ip",
+                     self.proxy.add_floating_ip_to_server,
+                     method_args=["value", "floating-ip"],
+                     expected_args=["floating-ip"],
+                     expected_kwargs={'fixed_address': None})
+
+    def test_add_floating_ip_to_server_with_fixed_addr(self):
+        self._verify("openstack.compute.v2.server.Server.add_floating_ip",
+                     self.proxy.add_floating_ip_to_server,
+                     method_args=["value", "floating-ip", 'fixed-addr'],
+                     expected_args=["floating-ip"],
+                     expected_kwargs={'fixed_address': 'fixed-addr'})
+
+    def test_remove_floating_ip_from_server(self):
+        self._verify("openstack.compute.v2.server.Server.remove_floating_ip",
+                     self.proxy.remove_floating_ip_from_server,
+                     method_args=["value", "address"],
+                     expected_args=["address"])
+
+    def test_server_backup(self):
+        self._verify("openstack.compute.v2.server.Server.backup",
+                     self.proxy.backup_server,
+                     method_args=["value", "name", "daily", 1],
+                     expected_args=["name", "daily", 1])
+
+    def test_server_pause(self):
+        self._verify("openstack.compute.v2.server.Server.pause",
+                     self.proxy.pause_server,
+                     method_args=["value"])
+
+    def test_server_unpause(self):
+        self._verify("openstack.compute.v2.server.Server.unpause",
+                     self.proxy.unpause_server,
+                     method_args=["value"])
+
+    def test_server_suspend(self):
+        self._verify("openstack.compute.v2.server.Server.suspend",
+                     self.proxy.suspend_server,
+                     method_args=["value"])
+
+    def test_server_resume(self):
+        self._verify("openstack.compute.v2.server.Server.resume",
+                     self.proxy.resume_server,
+                     method_args=["value"])
+
+    def test_server_lock(self):
+        self._verify("openstack.compute.v2.server.Server.lock",
+                     self.proxy.lock_server,
+                     method_args=["value"])
+
+    def test_server_unlock(self):
+        self._verify("openstack.compute.v2.server.Server.unlock",
+                     self.proxy.unlock_server,
+                     method_args=["value"])
+
+    def test_server_rescue(self):
+        self._verify("openstack.compute.v2.server.Server.rescue",
+                     self.proxy.rescue_server,
+                     method_args=["value"],
+                     expected_kwargs={"admin_pass": None, "image_ref": None})
+
+    def test_server_rescue_with_options(self):
+        self._verify("openstack.compute.v2.server.Server.rescue",
+                     self.proxy.rescue_server,
+                     method_args=["value", 'PASS', 'IMG'],
+                     expected_kwargs={"admin_pass": 'PASS',
+                                      "image_ref": 'IMG'})
+
+    def test_server_unrescue(self):
+        self._verify("openstack.compute.v2.server.Server.unrescue",
+                     self.proxy.unrescue_server,
+                     method_args=["value"])
+
+    def test_server_evacuate(self):
+        self._verify("openstack.compute.v2.server.Server.evacuate",
+                     self.proxy.evacuate_server,
+                     method_args=["value"],
+                     expected_kwargs={"host": None, "admin_pass": None,
+                                      "force": None})
+
+    def test_server_evacuate_with_options(self):
+        self._verify("openstack.compute.v2.server.Server.evacuate",
+                     self.proxy.evacuate_server,
+                     method_args=["value", 'HOST2', 'NEW_PASS', True],
+                     expected_kwargs={"host": "HOST2",
+                                      "admin_pass": 'NEW_PASS',
+                                      "force": True})
+
+    def test_server_start(self):
+        self._verify("openstack.compute.v2.server.Server.start",
+                     self.proxy.start_server,
+                     method_args=["value"])
+
+    def test_server_stop(self):
+        self._verify("openstack.compute.v2.server.Server.stop",
+                     self.proxy.stop_server,
+                     method_args=["value"])
+
+    def test_server_shelve(self):
+        self._verify("openstack.compute.v2.server.Server.shelve",
+                     self.proxy.shelve_server,
+                     method_args=["value"])
+
+    def test_server_unshelve(self):
+        self._verify("openstack.compute.v2.server.Server.unshelve",
+                     self.proxy.unshelve_server,
+                     method_args=["value"])
+
+    def test_get_server_output(self):
+        self._verify("openstack.compute.v2.server.Server.get_console_output",
+                     self.proxy.get_server_console_output,
+                     method_args=["value"],
+                     expected_kwargs={"length": None})
+
+        self._verify("openstack.compute.v2.server.Server.get_console_output",
+                     self.proxy.get_server_console_output,
+                     method_args=["value", 1],
+                     expected_kwargs={"length": 1})
+
     def test_availability_zones(self):
         self.verify_list_no_kwargs(self.proxy.availability_zones,
                                    az.AvailabilityZone,
@@ -296,7 +428,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
                       self.proxy.get_server_metadata,
                       method_args=["value"],
                       method_result=server.Server(id="value", metadata={}),
-                      expected_args=[self.session],
+                      expected_args=[self.proxy],
                       expected_result={})
 
     def test_set_server_metadata(self):
@@ -308,7 +440,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
                       method_kwargs=kwargs,
                       method_result=server.Server.existing(id=id,
                                                            metadata=kwargs),
-                      expected_args=[self.session],
+                      expected_args=[self.proxy],
                       expected_kwargs=kwargs,
                       expected_result=kwargs)
 
@@ -317,7 +449,7 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
                       self.proxy.delete_server_metadata,
                       expected_result=None,
                       method_args=["value", "key"],
-                      expected_args=[self.session, "key"])
+                      expected_args=[self.proxy, "key"])
 
     def test_server_group_create(self):
         self.verify_create(self.proxy.create_server_group,
@@ -356,10 +488,6 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
         self.verify_get(self.proxy.get_hypervisor,
                         hypervisor.Hypervisor)
 
-    def test_get_service(self):
-        self.verify_get(self.proxy.get_service,
-                        service.Service)
-
     def test_services(self):
         self.verify_list_no_kwargs(self.proxy.services,
                                    service.Service,
@@ -382,3 +510,9 @@ class TestComputeProxy(test_proxy_base2.TestProxyBase):
                      self.proxy.force_service_down,
                      method_args=["value", "host1", "nova-compute"],
                      expected_args=["host1", "nova-compute"])
+
+    def test_live_migrate_server(self):
+        self._verify('openstack.compute.v2.server.Server.live_migrate',
+                     self.proxy.live_migrate_server,
+                     method_args=["value", "host1", "force"],
+                     expected_args=["host1", "force"])
