@@ -11,7 +11,7 @@
 # under the License.
 
 import mock
-import testtools
+from openstack.tests.unit import base
 
 from openstack.compute.v2 import service
 
@@ -26,7 +26,7 @@ EXAMPLE = {
 }
 
 
-class TestService(testtools.TestCase):
+class TestService(base.TestCase):
 
     def setUp(self):
         super(TestService, self).setUp()
@@ -68,7 +68,7 @@ class TestService(testtools.TestCase):
             'forced_down': True,
         }
         self.sess.put.assert_called_with(
-            url, endpoint_filter=sot.service, json=body)
+            url, json=body)
 
     def test_enable(self):
         sot = service.Service(**EXAMPLE)
@@ -82,7 +82,7 @@ class TestService(testtools.TestCase):
             'host': 'host1',
         }
         self.sess.put.assert_called_with(
-            url, endpoint_filter=sot.service, json=body)
+            url, json=body)
 
     def test_disable(self):
         sot = service.Service(**EXAMPLE)
@@ -96,7 +96,7 @@ class TestService(testtools.TestCase):
             'host': 'host1',
         }
         self.sess.put.assert_called_with(
-            url, endpoint_filter=sot.service, json=body)
+            url, json=body)
 
     def test_disable_with_reason(self):
         sot = service.Service(**EXAMPLE)
@@ -113,4 +113,4 @@ class TestService(testtools.TestCase):
             'disabled_reason': reason
         }
         self.sess.put.assert_called_with(
-            url, endpoint_filter=sot.service, json=body)
+            url, json=body)
